# Generated by roxygen2: do not edit by hand

S3method("+",item_pool)
S3method("-",item_pool)
S3method("==",item_pool)
S3method("==",item_pool_cluster)
export(OAT)
export(Shadow)
export(Split)
export(Static)
export(TestDesign)
export(a_to_alpha)
export(app)
export(array_dirinfo_m_2pl)
export(array_dirinfo_m_3pl)
export(array_dirinfo_m_gpc)
export(array_dirinfo_m_gr)
export(array_e_1pl)
export(array_e_2pl)
export(array_e_3pl)
export(array_e_gpc)
export(array_e_gr)
export(array_e_pc)
export(array_h_1pl)
export(array_h_2pl)
export(array_h_3pl)
export(array_h_gpc)
export(array_h_gr)
export(array_h_pc)
export(array_info_1pl)
export(array_info_2pl)
export(array_info_3pl)
export(array_info_gpc)
export(array_info_gr)
export(array_info_m_2pl)
export(array_info_m_3pl)
export(array_info_m_gpc)
export(array_info_m_gr)
export(array_info_pc)
export(array_j_1pl)
export(array_j_2pl)
export(array_j_3pl)
export(array_j_gpc)
export(array_j_gr)
export(array_j_pc)
export(array_p_1pl)
export(array_p_2pl)
export(array_p_3pl)
export(array_p_gpc)
export(array_p_gr)
export(array_p_m_2pl)
export(array_p_m_3pl)
export(array_p_m_gpc)
export(array_p_m_gr)
export(array_p_pc)
export(array_thisdirinfo_m_2pl)
export(array_thisdirinfo_m_3pl)
export(array_thisdirinfo_m_gpc)
export(array_thisdirinfo_m_gr)
export(buildConstraints)
export(calcEscore)
export(calcFisher)
export(calcHessian)
export(calcJacobian)
export(calcLocation)
export(calcLogLikelihood)
export(calcProb)
export(calc_info)
export(calc_info_matrix)
export(calc_likelihood)
export(calc_likelihood_function)
export(calc_log_likelihood)
export(calc_log_likelihood_function)
export(calculateAdaptivityMeasures)
export(combineConstraints)
export(combineItemPool)
export(createShadowTestConfig)
export(createStaticTestConfig)
export(detectBestSolver)
export(dirinfo_m_2pl)
export(dirinfo_m_3pl)
export(dirinfo_m_gpc)
export(dirinfo_m_gr)
export(e_1pl)
export(e_2pl)
export(e_3pl)
export(e_gpc)
export(e_gr)
export(e_m_2pl)
export(e_m_3pl)
export(e_m_gpc)
export(e_m_gr)
export(e_pc)
export(eap)
export(find_segment)
export(getScoreAttributes)
export(getSolution)
export(getSolutionAttributes)
export(h_1pl)
export(h_2pl)
export(h_3pl)
export(h_gpc)
export(h_gr)
export(h_m_2pl)
export(h_m_3pl)
export(h_m_gpc)
export(h_m_gr)
export(h_pc)
export(info_1pl)
export(info_2pl)
export(info_3pl)
export(info_gpc)
export(info_gr)
export(info_m_2pl)
export(info_m_3pl)
export(info_m_gpc)
export(info_m_gr)
export(info_pc)
export(iparPosteriorSample)
export(j_1pl)
export(j_2pl)
export(j_3pl)
export(j_gpc)
export(j_gr)
export(j_m_2pl)
export(j_m_3pl)
export(j_m_gpc)
export(j_m_gr)
export(j_pc)
export(lnHyperPars)
export(loadConstraints)
export(loadItemAttrib)
export(loadItemPool)
export(loadStAttrib)
export(logitHyperPars)
export(makeConstraintsByEachPartition)
export(makeItemPoolCluster)
export(makeTest)
export(makeTestCluster)
export(mle)
export(mlef)
export(p_1pl)
export(p_2pl)
export(p_3pl)
export(p_gpc)
export(p_gr)
export(p_m_2pl)
export(p_m_3pl)
export(p_m_gpc)
export(p_m_gr)
export(p_pc)
export(plot)
export(print)
export(show)
export(simResp)
export(subsetConstraints)
export(subsetItemPool)
export(subsetTest)
export(summary)
export(testSolver)
export(theta_EAP)
export(theta_EAP_matrix)
export(theta_EB)
export(theta_EB_single)
export(theta_FB)
export(theta_FB_single)
export(thisdirinfo_m_2pl)
export(thisdirinfo_m_3pl)
export(thisdirinfo_m_gpc)
export(thisdirinfo_m_gr)
export(toggleConstraints)
exportClasses(config_Shadow)
exportClasses(config_Static)
exportClasses(constraint)
exportClasses(constraints)
exportClasses(item_pool)
exportClasses(output_Shadow)
exportClasses(output_Shadow_all)
exportClasses(output_Split)
exportClasses(output_Static)
exportClasses(simulation_data_cache)
exportClasses(test)
exportClasses(test_cluster)
exportMethods(Shadow)
exportMethods(Split)
exportMethods(Static)
exportMethods(as.data.frame)
exportMethods(calcFisher)
exportMethods(eap)
exportMethods(makeSimulationDataCache)
exportMethods(makeTest)
exportMethods(plot)
import(Rcpp)
import(crayon)
import(foreach)
import(lpSolve)
import(methods)
importFrom(grDevices,col2rgb)
importFrom(grDevices,dev.control)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.new)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,recordPlot)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,boxplot)
importFrom(graphics,grid)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,strheight)
importFrom(graphics,text)
importFrom(logitnorm,logit)
importFrom(logitnorm,rlogitnorm)
importFrom(methods,new)
importFrom(methods,show)
importFrom(methods,validObject)
importFrom(stats,aggregate)
importFrom(stats,cor)
importFrom(stats,dnorm)
importFrom(stats,dunif)
importFrom(stats,na.omit)
importFrom(stats,rlnorm)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,menu)
importFrom(utils,packageDescription)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(utils,write.table)
useDynLib(TestDesign)
